import json
from wtisdk import WtiClient
#from unittest.mock import Mock
import pytest
import requests

def test_get_status(mocker):
    # Load the mock response data from the JSON file
    with open('wtisdk/tests/fixtures/wti_get_status.json', 'r') as file:
        mock_response_data = json.load(file)
    
    # Mock the requests library and the response object
    mock_response = mocker.Mock()
    mock_response.status_code = 200
    mock_response.json.return_value = mock_response_data
    mocker.patch('requests.get', return_value=mock_response)
    
    # Create an instance of the WtiClient class
    client = WtiClient("10.20.30.139", "mteke", "password")
    
    # Call the get_status method
    result = client.get_status()
    
    # Assert the result matches the expected data
    assert result == mock_response_data

    
def test_get_alarm_status(mocker):
    # Load the mock response data from the JSON file
    with open('wtisdk/tests/fixtures/wti_get_alarm_status.json', 'r') as file:
        mock_response_data = json.load(file)

    # Mock the requests library and the response object
    mock_response = requests.Response()
    mock_response.status_code = 200
    mock_response.json = lambda: mock_response_data
    mocker.patch('requests.get', return_value=mock_response)

    # Create an instance of the WtiClient class
    client = WtiClient("10.20.30.139", "mteke", "password")

    # Call the get_alarm_status method
    result = client.get_alarm_status()

    # Assert the result matches the expected data
    assert result == mock_response_data



from setuptools import setup, find_packages

with open('README.md', 'r', encoding='utf-8') as fh:
    long_description = fh.read()

setup(
    name='wtisdk',
    version='1.5',
    author='Melih Teke',
    author_email='me@mteke.com',
    description='WTI SDK for interacting with WTI devices',
    long_description=f"{long_description}\n\nFor more information, visit the [PyPI page](https://pypi.org/project/wtisdk/).\n\nYou can also connect with me on [LinkedIn](https://www.linkedin.com/in/melih-teke/).",
    long_description_content_type='text/markdown',
    url='https://github.com/melihteke/wtisdk',
    packages=find_packages(),
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
    ],
    install_requires=[
        'requests',
        'urllib3',
    ],
)
